Stylo: Documentation
========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples/index.rst
   reference/index.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
